@@ -4,19 +4,73 @@ require 'open3'
 require 'optparse'
 require 'ostruct'
 
+def patch_files(options)
+  if options.java_bin == EZBake::Config[:java_bin]
+    yield
+  else
+    suffix = '.backup'
+    [
+      # Debian
+      '/etc/default/puppet*',
+      '/lib/systemd/system/puppet*.service',
+      # RPM
+      '/usr/lib/systemd/system/puppet*.service',
+      '/etc/sysconfig/puppet*',
+    ].each do |path|
+      Dir.glob(File.join(options.chdir, path)).each do |real_path|
+        content = File.read(real_path)
+        next unless content.include?(EZBake::Config[:java_bin])
+
+        warn "Copying #{real_path} to #{real_path}#{suffix}"
+        FileUtils.cp(real_path, "#{real_path}#{suffix}")
+        warn "Patching #{real_path} to use #{options.java_bin}"
+        File.write(real_path, content.gsub(EZBake::Config[:java_bin], options.java_bin))
+      end
+    end
+
+    yield
+
+    Dir.glob(File.join(options.chdir, '**', "*#{suffix}")).each do |path|
+      original = File.join(File.dirname(path), File.basename(path, suffix))
+      warn "Restoring #{path} to #{original}"
+      FileUtils.mv(path, original)
+    end
+  end
+end
+
 options = OpenStruct.new
+
+# ezbake.rb is rendered from
+# resources/puppetlabs/lein-ezbake/staging-templates/ezbake.rb.mustache
+#
+# inside the build container, fpm.rb is at:
+# /code/target/staging/puppetserver-8.9.0/ext/fpm.rb
+# ezbake:
+# /code/target/staging/ezbake.rb
+#
+# we do this hula hoop jump because in our build process the ezbake.rb exists
+# We also distribute a .tar.gz. This contains the compiled jar + fpm.rb.
+# fpm.rb is executed while we build the packages. This is the same process as
+# compiling the jar and rendering ezbake from
+# resources/puppetlabs/lein-ezbake/staging-templates/ezbake.rb.mustache
+# people that try to build their own package based on our tar, like FreeBSD, don't have the ezbake.rb
+#
+# patches welcome to move ezbake.rb into the tar *or* get rid of ezbake
+begin
+  require_relative '../../ezbake'
+rescue LoadError
+  options.java_bin = '/usr/bin/java'
+else
+  options.java_bin = EZBake::Config[:java_bin]
+end
+
 # settin' some defaults
-options.systemd = 0
-options.sysvinit = 0
 options.systemd_el = 0
 options.systemd_sles = 0
-options.old_el = 0
-options.old_sles = 0
 options.sles = 0
 options.java = 'java-1.8.0-openjdk-headless'
 options.release = 1
 options.platform_version = 0
-options.is_pe = false
 options.replaces = {}
 options.additional_dependencies = []
 options.user = 'puppet'
@@ -53,9 +107,6 @@ OptionParser.new do |opts|
   opts.on('--platform-version VERSION', Integer, 'VERSION of the puppet platform this builds for') do |v|
     options.platform_version = v
   end
-  opts.on('--[no-]enterprise-build', 'Whether or not this is a PE build') do |e|
-    options.is_pe = e
-  end
   opts.on('--replaces <PKG,VERSION>', Array, 'PKG and VERSION replaced by this package. Can be passed multiple times.') do |pkg,ver|
     options.replaces[pkg] = ver
   end
@@ -140,17 +191,9 @@ fail "--dist is required!" if options.output_type == 'deb' && options.dist.nil?
 if options.sources.empty?
   options.sources = case options.operating_system
                     when :amazon, :fedora, :sles, :el, :redhatfips
-                      if options.operating_system == :el && options.os_version < 7 || options.operating_system == :sles && options.os_version < 12 #sysv rpm platforms
-                        ['etc', 'opt', 'var']
-                      else
-                        ['etc', 'opt', 'usr', 'var']
-                      end
+                      ['etc', 'opt', 'usr', 'var']
                     when :debian, :ubuntu
-                      if options.dist == 'trusty' #trusty is the only sysv deb we build for right now
-                        ['etc', 'opt', 'var']
-                      else
-                        ['etc', 'lib', 'opt', 'usr', 'var']
-                      end
+                      ['etc', 'lib', 'opt', 'var']
                     else
                       fail "I don't know what your default sources should be, pass it on the command line!"
                     end
@@ -162,7 +205,6 @@ shared_opts = Array('')
 termini_opts = Array('')
 
 options.app_logdir = "/var/log/puppetlabs/#{options.realname}"
-options.app_rundir = "/var/run/puppetlabs/#{options.realname}"
 options.app_prefix = "/opt/puppetlabs/server/apps/#{options.realname}"
 options.app_data = "/opt/puppetlabs/server/data/#{options.realname}"
 
@@ -172,95 +214,47 @@ if options.output_type == 'rpm'
   shared_opts << "--rpm-digest sha256"
   shared_opts << "--rpm-rpmbuild-define 'rpmversion #{options.version}'"
   fpm_opts << "--rpm-rpmbuild-define '_app_logdir #{options.app_logdir}'"
-  fpm_opts << "--rpm-rpmbuild-define '_app_rundir #{options.app_rundir}'"
   fpm_opts << "--rpm-rpmbuild-define '_app_prefix #{options.app_prefix}'"
   fpm_opts << "--rpm-rpmbuild-define '_app_data #{options.app_data}'"
 
   if options.operating_system == :fedora # all supported fedoras are systemd
-    options.systemd = 1
     options.systemd_el = 1
   elsif options.operating_system == :amazon
-    if ! options.is_pe
-      fpm_opts << "--depends tzdata-java"
-      options.java = '(java-17-amazon-corretto-headless or java-11-amazon-corretto-headless)'
+    fpm_opts << "--depends tzdata-java"
+    options.java = '(java-17-amazon-corretto-headless or java-11-amazon-corretto-headless)'
+
+    options.systemd_el = 1
+  elsif options.operating_system == :el
+    if options.os_version == 7
+      options.java = 'jre-11-headless'
+      options.java_bin = '/usr/lib/jvm/jre-11/bin/java'
+    elsif (8..9).include?(options.os_version)
+      options.java = 'jre-17-headless'
+      options.java_bin = '/usr/lib/jvm/jre-17/bin/java'
+    elsif options.os_version == 10
+      options.java = 'jre-21-headless'
+      options.java_bin = '/usr/lib/jvm/jre-21/bin/java'
+    else
+      fail "Unrecognized el os version #{options.os_version}"
     end
 
-    options.systemd = 1
     options.systemd_el = 1
-  elsif options.operating_system == :el && options.os_version >= 7 # systemd el
-    if ! options.is_pe
-      fpm_opts << "--depends tzdata-java"
-      options.java =
-        case options.platform_version
-        when 8
-          # rpm on Redhat 7 may not support OR dependencies
-          if options.os_version == 7
-            'java-11-openjdk-headless'
-          elsif options.os_version == 8
-            '(java-17-openjdk-headless or java-11-openjdk-headless)'
-          elsif options.os_version >= 9
-            'java-17-openjdk-headless'
-          else
-            fail "Unrecognized el os version #{options.os_version}"
-          end
-        when 7
-          'java-1.8.0-openjdk-headless'
-        else
-          fail "Unknown Puppet Platform Version #{options.platform_version}"
-        end
-    end
-
-    options.systemd = 1
+  elsif options.operating_system == :redhatfips
     options.systemd_el = 1
-  elsif options.operating_system == :el # old el
-    options.sysvinit = 1
-    options.old_el = 1
-  elsif options.operating_system == :redhatfips && options.os_version >= 7 # systemd redhatfips
-    options.systemd = 1
-    options.systemd_el = 1
-  elsif options.operating_system == :sles && options.os_version >= 12 # systemd sles
-    options.systemd = 1
+  elsif options.operating_system == :sles
     options.systemd_sles = 1
     options.sles = 1
-    if ! options.is_pe
-      options.java =
-        case options.platform_version
-        when 8
-          'java-11-openjdk-headless'
-        when 7
-          if options.os_version > 12
-            'java-11-openjdk-headless'
-          else
-            'java-1_8_0-openjdk-headless'
-          end
-        else
-          fail "Unknown Puppet Platform Version #{options.platform_version}"
-        end
-    end
-  elsif options.operating_system == :sles #old sles
-    options.sysvinit = 1
-    options.old_sles = 1
+    options.java = 'java-11-openjdk-headless'
   end
 
-  fpm_opts << "--rpm-rpmbuild-define '_with_sysvinit #{options.sysvinit}'"
-  fpm_opts << "--rpm-rpmbuild-define '_with_systemd #{options.systemd}'"
-  fpm_opts << "--rpm-rpmbuild-define '_old_sles #{options.old_sles}'"
   fpm_opts << "--rpm-rpmbuild-define '_systemd_el #{options.systemd_el}'"
   fpm_opts << "--rpm-rpmbuild-define '_systemd_sles #{options.systemd_sles}'"
-  fpm_opts << "--rpm-rpmbuild-define '_old_el #{options.old_el}'"
   fpm_opts << "--rpm-rpmbuild-define '_sysconfdir /etc'"
   fpm_opts << "--rpm-rpmbuild-define '_prefix #{options.app_prefix}'"
-  fpm_opts << "--rpm-rpmbuild-define '_rundir /var/run'"
   fpm_opts << "--rpm-rpmbuild-define '__jar_repack 0'"
 
   shared_opts << "--rpm-dist #{options.dist}"
 
-  if options.old_el == 1
-    fpm_opts << "--depends chkconfig"
-  elsif options.old_sles == 1
-    fpm_opts << "--depends aaa_base"
-  end
-
   if options.systemd_el == 1
     fpm_opts << "--depends systemd"
   end
@@ -287,7 +281,6 @@ if options.output_type == 'rpm'
 
   fpm_opts << "--directories #{options.app_logdir}"
   fpm_opts << "--directories /etc/puppetlabs/#{options.realname}"
-  fpm_opts << "--directories #{options.app_rundir}"
   shared_opts << "--rpm-auto-add-directories"
   fpm_opts << "--rpm-auto-add-exclude-directories /etc/puppetlabs"
   shared_opts << "--rpm-auto-add-exclude-directories /opt/puppetlabs"
@@ -298,13 +291,8 @@ if options.output_type == 'rpm'
   fpm_opts << "--rpm-auto-add-exclude-directories /opt/puppetlabs/server/data"
   fpm_opts << "--rpm-auto-add-exclude-directories /usr/lib/systemd"
   fpm_opts << "--rpm-auto-add-exclude-directories /usr/lib/systemd/system"
-  fpm_opts << "--rpm-auto-add-exclude-directories /etc/init.d"
-  fpm_opts << "--rpm-auto-add-exclude-directories /etc/rc.d"
   fpm_opts << "--rpm-auto-add-exclude-directories /etc/logrotate.d"
-  fpm_opts << "--rpm-auto-add-exclude-directories /etc/rc.d/init.d"
-  fpm_opts << "--rpm-auto-add-exclude-directories /usr/lib/tmpfiles.d"
   fpm_opts << "--rpm-auto-add-exclude-directories /var/log/puppetlabs"
-  fpm_opts << "--rpm-auto-add-exclude-directories /var/run/puppetlabs"
   termini_opts << "--rpm-auto-add-exclude-directories /opt/puppetlabs/puppet"
   termini_opts << "--rpm-auto-add-exclude-directories /opt/puppetlabs/puppet/lib"
   termini_opts << "--rpm-auto-add-exclude-directories /opt/puppetlabs/puppet/lib/ruby"
@@ -324,7 +312,6 @@ if options.output_type == 'rpm'
   fpm_opts << "--rpm-attr 750,#{options.user},#{options.group}:/etc/puppetlabs/#{options.realname}"
   fpm_opts << "--rpm-attr 750,#{options.user},#{options.group}:#{options.app_logdir}"
   fpm_opts << "--rpm-attr -,#{options.user},#{options.group}:#{options.app_data}"
-  fpm_opts << "--rpm-attr 755,#{options.user},#{options.group}:#{options.app_rundir}"
 
   fpm_opts << "--edit"
   fpm_opts << "--category 'System Environment/Daemons'"
@@ -335,19 +322,13 @@ elsif options.output_type == 'deb'
     options.release = "#{options.release}+#{options.dist}"
   end
 
-  if ! options.is_pe
-    options.java = 'openjdk-17-jre-headless | openjdk-11-jre-headless'
-  end
+  options.java = 'openjdk-17-jre-headless | openjdk-11-jre-headless'
 
   fpm_opts << '--deb-build-depends cdbs'
   fpm_opts << '--deb-build-depends bc'
   fpm_opts << '--deb-build-depends mawk'
   fpm_opts << '--deb-build-depends lsb-release'
-  if options.is_pe
-    fpm_opts << '--deb-build-depends puppet-agent'
-  else
-    fpm_opts << '--deb-build-depends "ruby | ruby-interpreter"'
-  end
+  fpm_opts << '--deb-build-depends "ruby | ruby-interpreter"'
   fpm_opts << '--deb-priority optional'
   fpm_opts << '--category utils'
   options.deb_interest_triggers.each do |trigger|
@@ -374,28 +355,45 @@ shared_opts << "--url http://github.com/openvoxproject"
 shared_opts << "--architecture all"
 
 options.replaces.each do |pkg, version|
+  # Strip the surrounding quotes since we add them in a certain way here.
+  # We should probably just fix this in the core code by being smarter with
+  # as-ruby-literaly, but someone more familiar with Clojure can do that part.
+  pkg = pkg.delete_prefix("'").delete_suffix("'")
+  version = version.delete_prefix("'").delete_suffix("'") unless version.nil?
   if options.output_type == 'rpm'
-    fpm_opts << "--replaces '#{pkg} <= #{version}-1'"
-    fpm_opts << "--conflicts '#{pkg} <= #{version}-1'"
+    val = if version.nil? || version.empty?
+            "'#{pkg}'"
+          else
+            "'#{pkg} <= #{version}-1'"
+          end
+    fpm_opts << "--replaces #{val}"
+    fpm_opts << "--conflicts #{val}"
   elsif options.output_type == 'deb'
     # why debian, why.
-    fpm_opts << "--replaces '#{pkg} (<< #{version}-1openvox1)'"
-    fpm_opts << "--conflicts '#{pkg} (<< #{version}-1openvox1)'"
-    fpm_opts << "--replaces '#{pkg} (<< #{version}-1#{options.dist})'"
-    fpm_opts << "--conflicts '#{pkg} (<< #{version}-1#{options.dist})'"
+    if version.nil? || version.empty?
+      fpm_opts << "--replaces '#{pkg}'"
+      fpm_opts << "--conflicts '#{pkg}'"
+    else
+      fpm_opts << "--replaces '#{pkg} (<< #{version}-1voxpupuli1)'"
+      fpm_opts << "--conflicts '#{pkg} (<< #{version}-1voxpupuli1)'"
+      fpm_opts << "--replaces '#{pkg} (<< #{version}-1puppetlabs1)'"
+      fpm_opts << "--conflicts '#{pkg} (<< #{version}-1puppetlabs1)'"
+      fpm_opts << "--replaces '#{pkg} (<< #{version}-1#{options.dist})'"
+      fpm_opts << "--conflicts '#{pkg} (<< #{version}-1#{options.dist})'"
+    end
   end
 end
 
-if options.is_pe
-  fpm_opts << "--depends pe-java"
-  fpm_opts << "--depends pe-puppet-enterprise-release"
-  fpm_opts << "--depends pe-bouncy-castle-jars"
-else
-  fpm_opts << "--depends '#{options.java}'"
+# This is kludgy. Make it better one of these days for any package
+# that has a corresponding termini package.
+if options.name == "openvoxdb"
+  termini_opts << "--replaces 'puppetdb-termini'"
+  termini_opts << "--conflicts 'puppetdb-termini'"
 end
 
+fpm_opts << "--depends '#{options.java}'"
+
 fpm_opts << "--depends bash"
-fpm_opts << "--depends net-tools"
 fpm_opts << "--depends /usr/bin/which" if options.output_type == 'rpm'
 fpm_opts << "--depends adduser" if options.output_type == 'deb'
 fpm_opts << "--depends procps"
@@ -468,22 +466,24 @@ if options.debug
   puts "#{Dir.pwd}"
 end
 
-# fpm sends all output to stdout
-out, _, stat = Open3.capture3("#{fpm_editor} fpm #{fpm_opts.join(' ')}")
-fail "Error trying to run FPM for #{options.dist}!\n#{out}" unless stat.success?
-
-puts "#{out}"
-
-if options.termini
-  if options.debug
-    puts "=========================="
-    puts "FPM COMMAND"
-    puts "fpm #{termini_opts.join(' ')}"
-    puts "=========================="
-  end
-
+patch_files(options) do
   # fpm sends all output to stdout
-  out, _, stat = Open3.capture3("fpm #{termini_opts.join(' ')}")
-  fail "Error trying to run FPM for the termini for #{options.dist}!\n#{out}" unless stat.success?
+  out, _, stat = Open3.capture3("#{fpm_editor} fpm #{fpm_opts.join(' ')}")
+  fail "Error trying to run FPM for #{options.dist}!\n#{out}" unless stat.success?
+
   puts "#{out}"
+
+  if options.termini
+    if options.debug
+      puts "=========================="
+      puts "FPM COMMAND"
+      puts "fpm #{termini_opts.join(' ')}"
+      puts "=========================="
+    end
+
+    # fpm sends all output to stdout
+    out, _, stat = Open3.capture3("fpm #{termini_opts.join(' ')}")
+    fail "Error trying to run FPM for the termini for #{options.dist}!\n#{out}" unless stat.success?
+    puts "#{out}"
+  end
 end
